GMMVI: Gaussian Mixture Model Variational Inference
===================================================

Welcome to the documentation for GMMVI - a framework for optimizing Gaussian mixture models for variational inference.

If you don't quite know how you ended up here,
check out the :doc:`about` page, for more details on the problem setting and the underlying algorithms.

Just wanna know how do :ref:`install<installation>` and :ref:`use<usage>` the framework? :doc:`Get Started<get_started>`!

For a look under the hood, you can check the :doc:`api` or directly dig into the source on the
`Github page <https://github.com/OlegArenz/gmmvi>`_.

.. toctree::
   about
   get_started
   api
   references
   :hidden:

